@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.3.1)
- * Copyright (C) 2023 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.1)
+ * Copyright (C) 2024 The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -192,21 +192,27 @@ public class AnnotationPanel extends JPanel implements AwtRenderPanelI,
     renderer = new AnnotationRenderer();
   }
 
+  /**
+   * Responds to a mouse wheel movement by scrolling the annotations up or down.
+   * Annotation labels are scrolled via method adjustmentValueChanged when the
+   * vertical scrollbar is adjusted.
+   * <p>
+   * If shift is pressed, then scrolling is left or right instead, and is
+   * delegated to AlignmentPanel, so that both sequences and annotations are
+   * scrolled together.
+   * <p>
+   * This object is a MouseWheelListener to AnnotationLabels, so mouse wheel
+   * events over the labels are delegated to this method.
+   * <p>
+   * Note that this method may also be fired by scrolling with a gesture on a
+   * trackpad.
+   */
   @Override
   public void mouseWheelMoved(MouseWheelEvent e)
   {
     if (e.isShiftDown())
     {
-      e.consume();
-      double wheelRotation = e.getPreciseWheelRotation();
-      if (wheelRotation > 0)
-      {
-        av.getRanges().scrollRight(true);
-      }
-      else if (wheelRotation < 0)
-      {
-        av.getRanges().scrollRight(false);
-      }
+      ap.getSeqPanel().mouseWheelMoved(e);
     }
     else
     {
@@ -558,7 +564,7 @@ public class AnnotationPanel extends JPanel implements AwtRenderPanelI,
 
     for (int i = 0; i < aa.length; i++)
     {
-      if (aa[i].visible)
+      if (aa[i].isForDisplay())
       {
         height += aa[i].height;
       }
@@ -1225,7 +1231,7 @@ public class AnnotationPanel extends JPanel implements AwtRenderPanelI,
     int height = 0, lheight = 0;
     for (int i = 0; i < aa.length; i++)
     {
-      if (aa[i].visible)
+      if (aa[i].isForDisplay())
       {
         lheight = height;
         height += aa[i].height;
@@ -1269,8 +1275,8 @@ public class AnnotationPanel extends JPanel implements AwtRenderPanelI,
           if (!first)
           {
             tip.append("<br>");
+            first = false;
           }
-          first = false;
           tip.append(anns[i].label);
           String description = anns[i].annotations[column].description;
           if (description != null && description.length() > 0)
@@ -1284,7 +1290,7 @@ public class AnnotationPanel extends JPanel implements AwtRenderPanelI,
     else if (column < ann.annotations.length
             && ann.annotations[column] != null)
     {
-      tooltip = ann.annotations[column].description;
+      tooltip = getAnnotationBriefSummary(ann.annotations[column]);
     }
     // TODO abstract tooltip generator so different implementations can be built
     if (ann.graph == AlignmentAnnotation.CONTACT_MAP)
@@ -1328,7 +1334,37 @@ public class AnnotationPanel extends JPanel implements AwtRenderPanelI,
                 .highlightPositionsOn(ann.sequenceRef, highlightPos, null);
       }
     }
-    return tooltip;
+    return tooltip == null || tooltip.length() == 0 ? null : tooltip;
+  }
+
+  private static String getAnnotationBriefSummary(Annotation a)
+  {
+    StringBuilder ttSB = new StringBuilder();
+    if (a.secondaryStructure != 0 && a.secondaryStructure != ' ')
+    {
+      ttSB.append(a.secondaryStructure);
+    }
+    else if (a.description != null && a.description.trim().length() > 0)
+    {
+      ttSB.append(a.description);
+    }
+    else if (a.displayCharacter != null
+            && a.displayCharacter.trim().length() > 0)
+    {
+      ttSB.append(a.displayCharacter);
+    }
+    else if (!Float.isNaN(a.value))
+    {
+      if (a.value == Math.floor(a.value)) // likely integer value
+      {
+        ttSB.append(String.format("%.0f", a.value));
+      }
+      else // display as is
+      {
+        ttSB.append(String.valueOf(a.value));
+      }
+    }
+    return ttSB.toString();
   }
 
   /**
@@ -1351,7 +1387,8 @@ public class AnnotationPanel extends JPanel implements AwtRenderPanelI,
 
     if (column < ann.annotations.length && ann.annotations[column] != null)
     {
-      String description = ann.annotations[column].description;
+      String description = getAnnotationBriefSummary(
+              ann.annotations[column]);
       if (description != null && description.trim().length() > 0)
       {
         text.append("  ").append(description);
