@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.3.1)
- * Copyright (C) 2023 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -295,7 +295,7 @@ public abstract class GStructureChooser extends JPanel
       mainFrame.pack();
     } catch (Exception e)
     {
-      jalview.bin.Console.outPrintln(e); // for JavaScript TypeError
+      System.out.println(e); // for JavaScript TypeError
       e.printStackTrace();
     }
   }
@@ -849,11 +849,11 @@ public abstract class GStructureChooser extends JPanel
 
   protected void closeAction(int preferredHeight)
   {
-    // jalview.bin.Console.outPrintln(">>>>>>>>>> closing internal frame!!!");
-    // jalview.bin.Console.outPrintln("width : " + mainFrame.getWidth());
-    // jalview.bin.Console.outPrintln("heigh : " + mainFrame.getHeight());
-    // jalview.bin.Console.outPrintln("x : " + mainFrame.getX());
-    // jalview.bin.Console.outPrintln("y : " + mainFrame.getY());
+    // System.out.println(">>>>>>>>>> closing internal frame!!!");
+    // System.out.println("width : " + mainFrame.getWidth());
+    // System.out.println("heigh : " + mainFrame.getHeight());
+    // System.out.println("x : " + mainFrame.getX());
+    // System.out.println("y : " + mainFrame.getY());
     tempUserPrefs.put("structureChooser.width", pnl_filter.getWidth());
     tempUserPrefs.put("structureChooser.height", preferredHeight);
     tempUserPrefs.put("structureChooser.x", mainFrame.getX());
